@@ -202,6 +202,10 @@ void GlobalPlacer::create_boxes() {
             ::vector<double> cost;
             ::vector<double> x_data;
             auto dsp_columns = hidden_columns[blk_type];
+            // sanity check
+            if (reduced_width_ < static_cast<uint32_t>(width)) {
+                throw std::runtime_error("Invalid layout. Tile array is too small");
+            }
             for (uint32_t x = 0; x < reduced_width_ - width; x++) {
                 // try to place it on every x and then see how many blocks left
                 // TODO: fix DSP block height
@@ -980,7 +984,9 @@ GlobalPlacer::realize() {
             // TODO: fix MEM assignment
             // for now add 2 extra
             result[boxes_[index].id][blk_type] = {};
-            for (int i = 0; i < iter.second + 2; i++) {
+            auto total_num_blocks = std::min(static_cast<int>(cells.size()),
+                                                              iter.second + 2);
+            for (int i = 0; i < total_num_blocks; i++) {
                 auto cell_i = blk_index[i];
                 auto cell = cells[cell_i];
                 result[boxes_[index].id][blk_type].insert(cell);
